==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
var WebCardActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardActionsDescriptionMetadata, _super);
    function WebCardActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardActionsDescriptionMetadata.b = function (a) {
        if (WebCardActionsDescriptionMetadata.a == null) {
            WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
        }
        if (a.g(WebCardActionsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardActions");
        a.item("Orientation", "ExportedType:string:CardActionsOrientation");
        a.item("Orientation@names", "Vertical;Horizontal");
    };
    WebCardActionsDescriptionMetadata.d = function (a) {
        WebCardActionsDescriptionMetadata.b(a);
        a.u("WebCardActions", function () { return new WebCardActionsDescription(); });
        a.t("WebCardActions", WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.$t = markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
}(Base));
export { WebCardActionsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
var WebCardActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardActionsDescriptionMetadata, _super);
    function WebCardActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardActionsDescriptionMetadata.b = function (a) {
        if (WebCardActionsDescriptionMetadata.a == null) {
            WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
        }
        if (a.j(WebCardActionsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardActions");
        a.item("__tagNameWC", "String:igc-card-actions");
        a.item("Orientation", "ExportedType:string:CardActionsOrientation");
        a.item("Orientation@names", "Vertical;Horizontal");
    };
    WebCardActionsDescriptionMetadata.d = function (a) {
        WebCardActionsDescriptionMetadata.b(a);
        a.aa("WebCardActions", function () { return new WebCardActionsDescription(); });
        a.z("WebCardActions", WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.$t = markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
}(Base));
export { WebCardActionsDescriptionMetadata };
